@@ -497,11 +497,14 @@ OC.L10N.register(
     "Error" : "Error",
     "Active" : "Activa",
     "Expired" : "Caducó",
+    "Never" : "Enxamás",
     "Language" : "Llingua",
     "Country" : "País",
     "Status" : "Estáu",
     "Created at" : "Data de creación",
     "Limits" : "Llendes",
+    "Yes" : "Sí",
+    "No" : "Non",
     "_%n user_::_%n users_" : ["%n usuariu","%n usuarios"],
     "Installed version: {version}" : "Versión instalada: {version}",
     "Downloading …" : "Baxando…",
@@ -596,8 +599,6 @@ OC.L10N.register(
     "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
     "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
     "Leave conversation" : "Colar de la conversación",
-    "No" : "Non",
-    "Yes" : "Sí",
     "Delete conversation" : "Desaniciar la conversación",
     "Delete chat messages" : "Desaniciar los mensaxes de la charra",
     "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
@@ -613,6 +614,7 @@ OC.L10N.register(
     "This conversation is limited to the current participants" : "Esta conversación ta llendada a los participantes actuales",
     "Error occurred when opening or limiting the conversation" : "Prodúxose un error al abrir o llendar la conversación",
     "Open conversation" : "Abrir la conversación",
+    "Invalid language" : "La llingua ye inválida",
     "Error occurred while updating start time" : "Prodúxose un error mentanto s'anovaba la hora de comienzu",
     "Error occurred when locking the conversation" : "Prodúxose un error mentanto se bloquiaba la conversación",
     "Error occurred when unlocking the conversation" : "Prodúxose un error mentanto se desbloquiaba la conversación",
@@ -727,10 +729,6 @@ OC.L10N.register(
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
     "Reactions" : "Reaiciones",
-    "Today" : "Güei",
-    "Yesterday" : "Ayeri",
-    "A week ago" : "Hai una selmana",
-    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
     "No messages" : "Nun hai nengún mensaxe",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
@@ -839,7 +837,6 @@ OC.L10N.register(
     "End call" : "Finar la llamada",
     "Stop recording" : "Parar la grabación",
     "Send a reaction" : "Unviar una reaición",
-    "Default" : "Por defeutu",
     "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
     "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
     "Screensharing options" : "Opciones de la compartición de pantalla",
@@ -907,6 +904,7 @@ OC.L10N.register(
     "Show all polls" : "Amosar toles encuestes",
     "Show all voice messages" : "Amosar tolos mensaxe de voz",
     "Show all locations" : "Amosar tolos llugares",
+    "Default" : "Por defeutu",
     "Group" : "Grupu",
     "Team" : "Equipu",
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
@@ -960,6 +958,10 @@ OC.L10N.register(
     "Copy conversation link" : "Copiar l'enllaz de la conversación",
     "Media settings" : "Configuración multimedia",
     "Normal call" : "Llamada normal",
+    "Today" : "Güei",
+    "Yesterday" : "Ayeri",
+    "A week ago" : "Hai una selmana",
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
     "Close" : "Zarrar",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
 },
