@@ -521,6 +521,7 @@ OC.L10N.register(
     "Blocked" : "Αποκλεισμένος",
     "Active" : "Ενεργό",
     "Expired" : "Έληξε",
+    "Never" : "Ποτέ",
     "The trial could not be requested. Please try again later." : "Δεν ήταν δυνατή η αίτηση της δοκιμής. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
     "The account could not be deleted. Please try again later." : "Δεν ήταν δυνατή η διαγραφή του λογαριασμού. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
     "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Ο συνεργάτης μας Struktur AG παρέχει μια υπηρεσία όπου μπορεί να ζητηθεί ένας φιλοξενούμενος διακομιστής σηματοδότησης. Για αυτό πρέπει να συμπληρώσετε μόνο την παρακάτω φόρμα και το Nextcloud θα το ζητήσει. Μόλις ο διακομιστής ρυθμιστεί για εσάς, τα διαπιστευτήρια θα συμπληρωθούν αυτόματα. Αυτό θα αντικαταστήσει τις υπάρχουσες ρυθμίσεις διακομιστή σηματοδότησης.",
@@ -535,6 +536,8 @@ OC.L10N.register(
     "Created at" : "Έχει δημιουργηθεί στις",
     "Expires at" : "Λήγει στις",
     "Limits" : "Όρια",
+    "Yes" : "Ναι",
+    "No" : "Όχι",
     "Delete the signaling server account" : "Διαγραφή του λογαριασμού διακομιστή σηματοδότησης",
     "_%n user_::_%n users_" : ["%n χρήστης","%n χρήστες"],
     "Installed version: {version}" : "Εγκατεστημένη έκδοση: {version}",
@@ -574,6 +577,7 @@ OC.L10N.register(
     "Failed" : "Απέτυχε",
     "OK" : "OK",
     "Checking …" : "Έλεγχος ...",
+    "Federated user" : "Ομοσπονδιακός χρήστης",
     "Create rooms" : "Δημιουργία δωματίων",
     "Confirm" : "Επιβεβαίωση",
     "Reset" : "Επαναφορά",
@@ -658,8 +662,6 @@ OC.L10N.register(
     "Do you really want to delete all messages in \"{displayName}\"?" : "Θέλετε πραγματικά να διαγράψετε όλα τα μηνύματα στο \"{displayName}\"?",
     "Be careful, these actions cannot be undone." : "Προσέξτε, αυτές οι ενέργειες δεν μπορούν να αναιρεθούν.",
     "Leave conversation" : "Εγκατάλειψη συνομιλίας",
-    "No" : "Όχι",
-    "Yes" : "Ναι",
     "Delete conversation" : "Διαγραφή συνομιλίας",
     "Permanently delete this conversation." : "Οριστική διαγραφή αυτής της συνομιλίας.",
     "Permanently delete all the messages in this conversation." : "Οριστική διαγραφή όλων των μηνυμάτων σε αυτήν τη συνομιλία.",
@@ -740,6 +742,7 @@ OC.L10N.register(
     "The call is being recorded." : "Η κλήση καταγράφεται.",
     "Select a file" : "Επιλογή αρχείου",
     "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
+    "Blur" : "Θόλωμα",
     "Upload" : "Μεταφόρτωση",
     "Files" : "Αρχεία",
     "Message read by everyone who shares their reading status" : "Το μήνυμα διαβάστηκε από όλους όσους μοιράζονται την κατάσταση ανάγνωσής τους",
@@ -778,10 +781,6 @@ OC.L10N.register(
     "Sending message" : "Αποστολή μηνύματος",
     "Failed to send the message. Click to try again" : "Αποτυχία αποστολής του μηνύματος. Κάντε κλικ για να δοκιμάσετε ξανά ",
     "Not enough free space to upload file" : "Δεν επαρκεί ο ελεύθερος χώρος για τη μεταφόρτωση του αρχείου",
-    "Today" : "Σήμερα",
-    "Yesterday" : "Χθες",
-    "_%n day ago_::_%n days ago_" : ["%n ημέρα πριν","%n ημέρες πριν"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Κανένα μήνυμα",
     "Create a new group conversation" : "Δημιουργία νέας ομαδικής συζήτησης",
     "Add participants" : "Προσθήκη συμμετεχόντων",
@@ -887,7 +886,6 @@ OC.L10N.register(
     "End call" : "Τερματισμός κλήσης",
     "You will be able to join the call only after a moderator starts it." : "Μπορείτε να συμμετάσχετε στην κλήση μόνο μετά την εκκίνηση από τον συντονιστή.",
     "Recording" : "Καταγραφή",
-    "Default" : "Προεπιλεγμένο",
     "You are not allowed to enable screensharing" : "Δεν επιτρέπεται να ενεργοποιήσετε τον διαμοιρασμό οθόνης",
     "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
     "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
@@ -908,9 +906,6 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Η κοινή χρήση οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η χρήση σελίδας με HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
-    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
     "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
     "Show your screen" : "Εμφάνιση της οθόνης σας",
     "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
@@ -918,6 +913,7 @@ OC.L10N.register(
     "Start recording" : "Έναρξη εγγραφής",
     "Select a region" : "Επιλογή περιοχής",
     "Submit" : "Υποβολή",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Μήνυμα χωρίς αναφορά σε κάποιον",
     "Mention myself" : "Αναφορά στον εαυτό μου",
     "The conversation does not exist" : "Η συνομιλία δεν υπάρχει",
@@ -975,6 +971,7 @@ OC.L10N.register(
     "Audio" : "Ήχος",
     "Other" : "Άλλο",
     "Show all files" : "Εμφάνιση όλων των αρχείων",
+    "Default" : "Προεπιλεγμένο",
     "Group" : "Ομάδα",
     "You: {lastMessage}" : "Εσείς: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
@@ -1030,10 +1027,16 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "Ο {user} σας προσκάλεσε σε προσωπική συζήτηση",
     "Always show the device preview screen before joining a call in this conversation." : "Να εμφανίζεται πάντα η οθόνη προεπισκόπησης της συσκευής πριν συμμετάσχετε σε μια κλήση σε αυτήν τη συνομιλία.",
     "Copy conversation link" : "Αντιγραφή συνδέσμου συνομιλίας",
+    "Today" : "Σήμερα",
+    "Yesterday" : "Χθες",
+    "_%n day ago_::_%n days ago_" : ["%n ημέρα πριν","%n ημέρες πριν"],
     "Close" : "Κλείσιμο",
     "Choose devices" : "Επιλέξτε συσκευές",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα πριν την έναρξη ή συμμετοχή σε μια κλήση.",
     "Blur background" : "Θόλωμα φόντου",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
+    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
     "Nextcloud Talk was updated, please reload the page" : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα",
     "Failed to join the conversation. Try to reload the page." : "Η συμμετοχή στη συνομιλία απέτυχε. Προσπαθήστε να φορτώσετε ξανά τη σελίδα.",
     "Nextcloud is in maintenance mode, please reload the page" : "Το Nextcloud βρίσκεται σε λειτουργία συντήρησης, ανανεώστε τη σελίδα",
