@@ -47,6 +47,7 @@ OC.L10N.register(
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
+    "Never" : "Nunca",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
@@ -97,6 +98,7 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
+    "Home" : "Inicio",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
     "Devices" : "Dispositivos",
@@ -107,10 +109,6 @@ OC.L10N.register(
     "Translate" : "Traducir",
     "Dismiss" : "Descartar",
     "Contact" : "Contacto",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create new poll" : "Crear nueva encuesta",
     "Send" : "Enviar",
     "Create poll" : "Crear encuesta",
@@ -127,17 +125,14 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
     "More actions" : "Más acciones",
-    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
     "Submit" : "Enviar",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "User" : "Usuario",
     "Password" : "Contraseña",
@@ -148,6 +143,7 @@ OC.L10N.register(
     "Polls" : "Encuestas",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Default" : "Predeterminado",
     "Group" : "Grupo",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Away" : "Lejos",
@@ -162,6 +158,12 @@ OC.L10N.register(
     "iOS app" : "Aplicación iOS",
     "__language_name__" : "Español (Dominican Republic)",
     "Tasks" : "Tareas",
-    "Close" : "Cerrar"
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Close" : "Cerrar",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
