@@ -459,6 +459,7 @@ OC.L10N.register(
     "Blocked" : "Blokuota",
     "Active" : "Aktyvi",
     "Expired" : "Nebegalioja",
+    "Never" : "Niekada",
     "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
     "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
     "Email of the user" : "Naudotojo el. paštas",
@@ -467,6 +468,8 @@ OC.L10N.register(
     "Status" : "Būsena",
     "Created at" : "Sukurta",
     "Expires at" : "Baigia galioti",
+    "Yes" : "Taip",
+    "No" : "Ne",
     "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
     "Installed version: {version}" : "Įdiegta versija: {version}",
     "Downloading …" : "Atsisiunčiama…",
@@ -601,8 +604,6 @@ OC.L10N.register(
     "Error while clearing chat history" : "Klaida išvalant pokalbio istoriją",
     "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
     "Leave conversation" : "Išeiti iš pokalbio",
-    "No" : "Ne",
-    "Yes" : "Taip",
     "Delete conversation" : "Ištrinti pokalbį",
     "Permanently delete this conversation." : "Ištrinti šį pokalbį visam laikui.",
     "_%n hour_::_%n hours_" : ["%n valanda","%n valandos","%n valandų","%n valanda"],
@@ -620,6 +621,7 @@ OC.L10N.register(
     "Resend invitations" : "Siųsti pakvietimus iš naujo",
     "This conversation is open to registered users" : "Šis pokalbis yra atviras registruotiems naudotojams",
     "Open conversation" : "Atverti pokalbį",
+    "Invalid language" : "Neteisinga kalba",
     "Start time: {date}" : "Pradžios laikas: {date}",
     "Start time has been updated" : "Pradžios laikas atnaujintas",
     "Error occurred while updating start time" : "Atnaujinant pradžios laiką, įvyko klaida",
@@ -744,11 +746,6 @@ OC.L10N.register(
     "Show all reactions" : "Rodyti visas reakcijas",
     "Add more reactions" : "Pridėti daugiau reakcijų",
     "Reactions" : "Reakcijos",
-    "Today" : "Šiandien",
-    "Yesterday" : "Vakar",
-    "A week ago" : "Prieš savaitę",
-    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Nėra laiškų",
     "Cancel search" : "Atsisakyti paieškos",
     "Add a phone number" : "Pridėti telefono numerį",
@@ -844,7 +841,6 @@ OC.L10N.register(
     "Raise or lower hand" : "Pakelti ar nuleisti ranką",
     "More actions" : "Daugiau veiksmų",
     "Start call" : "Pradėti skambutį",
-    "Default" : "Numatytoji",
     "You are not allowed to enable screensharing" : "Jums neleidžiama įjungti ekrano bendrinimo",
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
@@ -853,9 +849,6 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
-    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
@@ -866,6 +859,7 @@ OC.L10N.register(
     "Select a region" : "Pasirinkti regioną",
     "Submit" : "Pateikti",
     "Search …" : "Ieškoti…",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Rašyti be paminėjimo",
     "Mention myself" : "Paminėti save",
     "The conversation does not exist" : "Pokalbio nėra",
@@ -909,6 +903,7 @@ OC.L10N.register(
     "Other" : "Kita",
     "Show all media" : "Rodyti visą mediją",
     "Show all files" : "Rodyti visus failus",
+    "Default" : "Numatytoji",
     "Group" : "Grupė",
     "Team" : "Komanda",
     "You: {lastMessage}" : "Jūs: {lastMessage}",
@@ -960,10 +955,17 @@ OC.L10N.register(
     "Refresh devices list" : "Įkelti iš naujo įrenginių sąrašą",
     "Media settings" : "Medijos nustatymai",
     "Always show preview for this conversation" : "Visada rodyti šio pokalbio peržiūrą",
+    "Today" : "Šiandien",
+    "Yesterday" : "Vakar",
+    "A week ago" : "Prieš savaitę",
+    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
     "Close" : "Užverti",
     "Choose devices" : "Pasirinkti įrenginius",
     "Next call" : "Kitas skambutis",
     "Blur background" : "Sulieti foną",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
+    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
     "An error happened when trying to share your file" : "Bandant bendrinti jūsų failą įvyko klaida",
     "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
