@@ -9,7 +9,7 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2} and {user3}" : "Присуствувавте на повик со {user1}, {user2} и {user3}",
     "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Присуствувавте на повик со {user1}, {user2}, {user3} и {user4}",
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Присуствувавте на повик со {user1}, {user2}, {user3}, {user4} и {user5}",
-    "_%n other_::_%n others_" : ["уште 1","%n други"],
+    "_%n other_::_%n others_" : ["уште %n","%n други"],
     "{actor} invited you to {call}" : "{actor} ве покани во {call}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Поканети сте во <strong>разговор</strong> или имате <strong>повик</strong>",
     "Other activities" : "Други активности",
@@ -542,6 +542,7 @@ OC.L10N.register(
     "Blocked" : "Блокирани",
     "Active" : "Активно",
     "Expired" : "Истечен",
+    "Never" : "Никогаш",
     "URL of this Nextcloud instance" : "URL од оваа Nextcloud истанца",
     "Language" : "Јазик",
     "Country" : "Држава",
@@ -549,6 +550,8 @@ OC.L10N.register(
     "Created at" : "Создадено на",
     "Expires at" : "Истекува на",
     "Limits" : "Ограничувања",
+    "Yes" : "Да",
+    "No" : "Не",
     "_%n user_::_%n users_" : ["1 корисник","%n корисници"],
     "Installed version: {version}" : "Инсталирана верзија: {version}",
     "Downloading …" : "Преземање ...",
@@ -707,6 +710,7 @@ OC.L10N.register(
     "Error while accessing microphone" : "Грешка при пристап до микрофон",
     "Access to camera is only possible with HTTPS" : "Пристап до камерата е возможен само преку безбедноска врска HTTPS",
     "Invalid path selected" : "Избрана невалидна патека",
+    "Blur" : "Замаглување",
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
     "Message sent" : "Пораката е испратена",
@@ -740,10 +744,6 @@ OC.L10N.register(
     "Poll • Ended" : "Анкета • Завршена",
     "Poll" : "Анкета",
     "See results" : "Vidi rezultati",
-    "Today" : "Денес",
-    "Yesterday" : "Вчера",
-    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Нема пораки",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Add participants" : "Додади учесници",
@@ -889,7 +889,6 @@ OC.L10N.register(
     "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
     "Send a reaction" : "Испрати реакција",
     "React with {reaction}" : "Реагирај со {reaction}",
-    "Default" : "Стандардно",
     "_%n participant in call_::_%n participants in call_" : ["%n учесник во повикот","%n учесници во повикот"],
     "You are not allowed to enable screensharing" : "Не сте овластени да го овозможите споделување на екранот",
     "No screensharing" : "Нема споделување на екран",
@@ -913,9 +912,6 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
     "Screen sharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
-    "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
     "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
@@ -925,6 +921,7 @@ OC.L10N.register(
     "Select a region" : "Изберете регион",
     "Submit" : "Испрати",
     "Search …" : "Пребарај ...",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Пораки без спомнувања",
     "Mention myself" : "Спомни се себеси",
     "The conversation does not exist" : "Разговорот не постои",
@@ -959,6 +956,7 @@ OC.L10N.register(
     "Show all locations" : "Прикажи ги сите локации",
     "Show all audio" : "Прикажи ги сите звуци",
     "Show all other" : "Прикажи ги сите останати",
+    "Default" : "Стандардно",
     "Group" : "Група",
     "Team" : "Тим",
     "You: {lastMessage}" : "Ти: {lastMessage}",
@@ -1014,9 +1012,15 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} те покани на приватен разговор",
     "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
     "Copy conversation link" : "копирај линк од разговорот",
+    "Today" : "Денес",
+    "Yesterday" : "Вчера",
+    "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
     "Close" : "Затвори",
     "Choose devices" : "Избери уреди",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
+    "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
     "Nextcloud Talk was updated, please reload the page" : "Разговорот е ажуриран, повторно вчитајте ја страната",
     "An error happened when trying to share your file" : "Се случи грешка при обидот за споделување на датотека",
     "Failed to join the conversation. Try to reload the page." : "Неуспешно приклучување кон разговорот, Пробајте да ја превчитате страницата.",
