@@ -545,6 +545,7 @@ OC.L10N.register(
     "Blocked" : "Blocat",
     "Active" : "Activa",
     "Expired" : "Expirat",
+    "Never" : "Jamai",
     "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
     "Email of the user" : "Email de l’utilizaire",
     "Language" : "Lenga",
@@ -553,6 +554,8 @@ OC.L10N.register(
     "Created at" : "Creat lo",
     "Expires at" : "Expira lo",
     "Limits" : "Limits",
+    "Yes" : "Òc",
+    "No" : "Non",
     "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
     "Installed version: {version}" : "Version installada : {version}",
     "Downloading …" : "Telecargament…",
@@ -595,6 +598,14 @@ OC.L10N.register(
     "Save" : "Salvar",
     "Search participants" : "Cercar participants",
     "No results" : "Pas cap de resultat",
+    "Raise hand" : "Levar la man",
+    "Raise hand (R)" : "Levar la man (R)",
+    "Lower hand" : "Baissar la man",
+    "Lower hand (R)" : "Baissar la man (R)",
+    "Exit full screen (F)" : "Sortir de l'ecran complèt (F)",
+    "Full screen (F)" : "Ecran complèt (F)",
+    "Speaker view" : "Vista parlaire",
+    "Grid view" : "Vista en grasilha",
     "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
     "{nickName} raised their hand." : "{nickName} a levat la man.",
     "A participant raised their hand." : "Un participant a levat la man.",
@@ -614,6 +625,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Copar lo son (M)",
     "Unmute audio" : "Restablir lo son",
     "Unmute audio (M)" : "Restablir lo son (M)",
+    "None" : "Pas cap",
     "Access to camera was denied" : "L’accès a la camèra es estat refusat",
     "Error while accessing camera: It is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utilize",
     "Error while accessing camera" : "Error pendent l’accès a la camèra",
@@ -651,9 +663,9 @@ OC.L10N.register(
     "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
     "Picture" : "Imatge",
     "Disable" : "Desactivar",
+    "Choose your conversation picture" : "Causissètz un imatge de conversacion",
     "Choose" : "Causir",
     "Set picture" : "Definir l'imatge",
-    "Choose your conversation picture" : "Causissètz un imatge de conversacion",
     "Default permissions modified for {conversationName}" : "Permissions per defaut modificadas per {conversationName}",
     "Could not modify default permissions for {conversationName}" : "Las permissions per defaut se podiá pas modificar {conversationName}",
     "All permissions" : "Totas las permissions",
@@ -672,8 +684,6 @@ OC.L10N.register(
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
-    "No" : "Non",
-    "Yes" : "Òc",
     "Delete conversation" : "Suprimir la conversacion",
     "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "Delete chat messages" : "Suprimir los messatges del chat",
@@ -741,7 +751,6 @@ OC.L10N.register(
     "The meeting will start soon" : "La conferéncia començarà lèu",
     "This meeting is scheduled for {startTime}" : "La conferéncia es planificada per {startTime}",
     "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
-    "None" : "Pas cap",
     "Select microphone" : "Causir microfòn",
     "No microphone available" : "Cap de microfòn pas disponible",
     "Select camera" : "Causir una camèra",
@@ -755,7 +764,6 @@ OC.L10N.register(
     "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
     "Error while accessing microphone" : "Error pendent l’accès al microfòn",
     "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
-    "Media settings" : "Paramètres dels mèdias",
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
@@ -799,10 +807,6 @@ OC.L10N.register(
     "Poll • Ended" : "Sondatge・Terminat",
     "Poll" : "Sondatge",
     "See results" : "Veire los resultats",
-    "Today" : "Uèi",
-    "Yesterday" : "Ièr",
-    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Cap de messatge",
     "Cancel search" : "Anullar la recèrca",
     "Add a phone number" : "Apondre un numèro de telefòn",
@@ -814,9 +818,9 @@ OC.L10N.register(
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Joining conversation …" : "Dintra dins la conversacion…",
     "Send message" : "Enviar un messatge",
+    "File to share" : "Fichièr de partejar",
     "Add emoji" : "Apondre emoji",
     "Cancel editing" : "Anullar la modificacion",
-    "File to share" : "Fichièr de partejar",
     "Share from Files" : "Partejar a partir dels Fichièrs",
     "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
     "Record voice message" : "Enregistrar messatge vocal",
@@ -898,6 +902,7 @@ OC.L10N.register(
     "Shared items" : "Elements partejats",
     "Load more results" : "Cargar mai de resultats",
     "Projects" : "Projèctes",
+    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Link to a conversation" : "Ligam cap a la conversacion",
     "Search conversations or users" : "Cercar de conversacions o utilizaires",
     "Select conversation" : "Seleccionar una conversacion",
@@ -910,6 +915,7 @@ OC.L10N.register(
     "Display name: {name}" : "Nom d’afichatge : {name}",
     "Save name" : "Enregistrar lo nom",
     "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
+    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
     "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
     "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
@@ -918,7 +924,6 @@ OC.L10N.register(
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
     "Attachments folder" : "Dossièr de pèças-juntas",
     "Browse …" : "Percórrer...",
-    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Privacy" : "Confidencialitat",
     "Sounds" : "Sons",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
@@ -932,6 +937,7 @@ OC.L10N.register(
     "Space bar" : "barra d’espaci",
     "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Raise or lower hand" : "Levar o baissar la man",
+    "More actions" : "Mai d’accions",
     "Start call silently" : "Començar la sonada en silenci",
     "Start call" : "Començar sonada",
     "End call" : "Acabar la sonada",
@@ -942,8 +948,6 @@ OC.L10N.register(
     "Stop recording" : "Arrestar l'enregistrament",
     "Send a reaction" : "Enviar una reaccion",
     "React with {reaction}" : "Reagir amb {reaction}",
-    "Disable background blur" : "Desactivar lo rèireplan trebol",
-    "Blur background" : "Rèireplan trebol",
     "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
     "No screensharing" : "Cap de partiment d’ecran",
     "Screensharing options" : "Opcion de partiment d’ecran",
@@ -951,6 +955,7 @@ OC.L10N.register(
     "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
     "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
+    "Disable background blur" : "Desactivar lo rèireplan trebol",
     "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
@@ -964,26 +969,16 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
-    "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
-    "Exit full screen (F)" : "Sortir de l'ecran complèt (F)",
-    "Full screen (F)" : "Ecran complèt (F)",
-    "Speaker view" : "Vista parlaire",
-    "Grid view" : "Vista en grasilha",
-    "Raise hand" : "Levar la man",
-    "Raise hand (R)" : "Levar la man (R)",
-    "Lower hand" : "Baissar la man",
-    "Lower hand (R)" : "Baissar la man (R)",
     "Mute others" : "Copar lo son dels autres",
-    "Toggle full screen" : "Alternar ecran complèt",
     "Start recording" : "Lançar l'enregistrament",
+    "Toggle full screen" : "Alternar ecran complèt",
     "Select a region" : "Seleccionatz una region",
     "Submit" : "Transmetre",
     "Search …" : "Recercar...",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Messatge sens mencion",
     "Mention myself" : "Me mencionar",
     "The conversation does not exist" : "La conversacion existís pas",
@@ -1047,9 +1042,9 @@ OC.L10N.register(
     "Show all call recordings" : "Mostrar los enregistraments de sonadas",
     "Show all audio" : "Veire totes los àudios",
     "Show all other" : "Veire tota la rèsta",
+    "Default" : "Defaut",
     "Group" : "Grop",
     "You: {lastMessage}" : "Vos : {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Leave this page" : "Quitar aquesta pagina",
     "Join here" : "Rejónher aquí",
     "Post to a conversation" : "Publicar dins una conversacion",
@@ -1084,7 +1079,6 @@ OC.L10N.register(
     "Please reload the page." : "Volgatz recargar la pagina.",
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
-    "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
     "Speaker {number}" : "Naut-parlaire {number}",
@@ -1110,9 +1104,17 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Copy conversation link" : "Copiar lo ligam de conversacion",
+    "Media settings" : "Paramètres dels mèdias",
+    "Today" : "Uèi",
+    "Yesterday" : "Ièr",
+    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
     "Close" : "Tampar",
     "Choose devices" : "Causir periferics",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
+    "Blur background" : "Rèireplan trebol",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
+    "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
     "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
