@@ -172,10 +172,12 @@ OC.L10N.register(
     "Pending" : "Në Pritje të Konfirmimit",
     "Error" : "Error",
     "Blocked" : "I bllokuar",
+    "Never" : "Kurrë",
     "Language" : "Gjuha",
     "Country" : "Vend",
     "Status" : "Status",
     "Created at" : "U krijua në",
+    "Yes" : "Po",
     "TURN server protocols" : "Protokollet e serverit TURN",
     "OK" : "OK",
     "Checking …" : "Duke kontrolluar ...",
@@ -204,7 +206,6 @@ OC.L10N.register(
     "Restricted" : "I/E kufizuar",
     "Personal" : "Personale",
     "Leave conversation" : "Largohuni nga biseda",
-    "Yes" : "Po",
     "Delete conversation" : "Fshijeni bisedën",
     "Password protection" : "Password protection",
     "Set a password" : "Vendosni një fjalëkalim",
@@ -228,9 +229,6 @@ OC.L10N.register(
     "Translate" : "Përkthe",
     "Dismiss" : "Hiq",
     "Contact" : "Kontakt",
-    "Today" : "Sot",
-    "Yesterday" : "Dje",
-    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
     "Send message" : "Dërgo mesazh",
     "Create new poll" : "Krijo sondazh të ri",
     "New file" : "Skedë e re",
@@ -245,11 +243,7 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
     "More actions" : "Më tepër veprime ",
-    "Default" : "E paracaktuar",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
-    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
@@ -265,6 +259,7 @@ OC.L10N.register(
     "Polls" : "Sondazhe",
     "Audio" : "Audio",
     "Other" : "Tjetër",
+    "Default" : "E paracaktuar",
     "Group" : "Grup",
     "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
@@ -277,6 +272,12 @@ OC.L10N.register(
     "iOS app" : "Aplikacion iOS",
     "__language_name__" : "Shqip",
     "Tasks" : "Detyra",
-    "Close" : "Mbylleni"
+    "Today" : "Sot",
+    "Yesterday" : "Dje",
+    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
+    "Close" : "Mbylleni",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
+    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj."
 },
 "nplurals=2; plural=(n != 1);");
