@@ -2,28 +2,15 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2017, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat\Parser;
 
+use OCA\Circles\CirclesManager;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Events\MessageParseEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\GuestManager;
 use OCA\Talk\Model\Attendee;
@@ -31,45 +18,51 @@ use OCA\Talk\Model\Message;
 use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
+use OCP\App\IAppManager;
 use OCP\Comments\ICommentsManager;
+use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventListener;
+use OCP\Federation\ICloudIdManager;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IL10N;
 use OCP\IUserManager;
+use OCP\Server;
 
 /**
  * Helper class to get a rich message from a plain text message.
+ * @template-implements IEventListener<Event>
  */
-class UserMention {
-	/**
-	 * Do NOT inject OCA\Talk\Chat\CommentsManager here
-	 * otherwise the display name resolvers are lost
-	 * and mentions are not replaced anymore.
-	 */
-	protected ICommentsManager $commentsManager;
-	protected IUserManager $userManager;
-	protected IGroupManager $groupManager;
-	protected GuestManager $guestManager;
-	protected ParticipantService $participantService;
-	protected AvatarService $avatarService;
-	protected IL10N $l;
+class UserMention implements IEventListener {
+	/** @var array<string, string> */
+	protected array $circleNames = [];
+	/** @var array<string, string> */
+	protected array $circleLinks = [];
 
 	public function __construct(
-		ICommentsManager $commentsManager,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
-		GuestManager $guestManager,
-		AvatarService $avatarService,
-		ParticipantService $participantService,
-		IL10N $l,
+		protected IAppManager $appManager,
+		protected ICommentsManager $commentsManager,
+		protected IUserManager $userManager,
+		protected IGroupManager $groupManager,
+		protected GuestManager $guestManager,
+		protected AvatarService $avatarService,
+		protected ICloudIdManager $cloudIdManager,
+		protected ParticipantService $participantService,
+		protected IL10N $l,
 	) {
-		$this->commentsManager = $commentsManager;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
-		$this->guestManager = $guestManager;
-		$this->participantService = $participantService;
-		$this->avatarService = $avatarService;
-		$this->l = $l;
+	}
+
+	public function handle(Event $event): void {
+		if (!$event instanceof MessageParseEvent) {
+			return;
+		}
+
+		$message = $event->getMessage();
+		if ($message->getMessageType() !== ChatManager::VERB_MESSAGE) {
+			return;
+		}
+
+		$this->parseMessage($message);
 	}
 
 	/**
@@ -85,21 +78,33 @@ class UserMention {
 	 *
 	 * @param Message $chatMessage
 	 */
-	public function parseMessage(Message $chatMessage): void {
+	protected function parseMessage(Message $chatMessage): void {
 		$comment = $chatMessage->getComment();
 		$message = $chatMessage->getMessage();
 		$messageParameters = $chatMessage->getMessageParameters();
 
 		$mentionTypeCount = [];
 
+		// Set the current message as comment content, so that the message finds
+		// mentions which are now part of the message, but were not on the original
+		// comment, e.g. mentions at the beginning of captions
+		$originalCommentMessage = $comment->getMessage();
+		$comment->setMessage($message, ChatManager::MAX_CHAT_LENGTH + 10000);
 		$mentions = $comment->getMentions();
+		$comment->setMessage($originalCommentMessage, ChatManager::MAX_CHAT_LENGTH);
+
 		// TODO This can be removed once getMentions() returns sorted results (Nextcloud 21+)
 		usort($mentions, static function (array $m1, array $m2) {
 			return mb_strlen($m2['id']) <=> mb_strlen($m1['id']);
 		});
 
+		$metadata = $comment->getMetaData() ?? [];
 		foreach ($mentions as $mention) {
 			if ($mention['type'] === 'user' && $mention['id'] === 'all') {
+				if (!isset($metadata[Message::METADATA_CAN_MENTION_ALL])) {
+					continue;
+				}
+
 				$mention['type'] = 'call';
 			}
 
@@ -116,35 +121,47 @@ class UserMention {
 			$mentionTypeCount[$mention['type']]++;
 
 			$search = $mention['id'];
-			if ($mention['type'] === 'group') {
-				$search = 'group/' . $mention['id'];
+			if (
+				$mention['type'] === 'email' ||
+				$mention['type'] === 'group' ||
+				// $mention['type'] === 'federated_group' ||
+				 $mention['type'] === 'team' ||
+				// $mention['type'] === 'federated_team' ||
+				$mention['type'] === 'federated_user') {
+				$search = $mention['type'] . '/' . $mention['id'];
 			}
 
 			// To keep a limited character set in parameter IDs ([a-zA-Z0-9-])
 			// the mention parameter ID does not include the mention ID (which
 			// could contain characters like '@' for user IDs) but a one-based
 			// index of the mentions of that type.
-			$mentionParameterId = 'mention-' . $mention['type'] . $mentionTypeCount[$mention['type']];
+			$mentionParameterId = 'mention-' . str_replace('_', '-', $mention['type']) . $mentionTypeCount[$mention['type']];
 
 			$message = str_replace('@"' . $search . '"', '{' . $mentionParameterId . '}', $message);
-			if (strpos($search, ' ') === false
-				&& strpos($search, 'guest/') !== 0
-				&& strpos($search, 'group/') !== 0) {
+			if (!str_contains($search, ' ')
+				&& !str_starts_with($search, 'guest/')
+				&& !str_starts_with($search, 'email/')
+				&& !str_starts_with($search, 'group/')
+				// && !str_starts_with($search, 'federated_group/')
+				 && !str_starts_with($search, 'team/')
+				// && !str_starts_with($search, 'federated_team/')
+				&& !str_starts_with($search, 'federated_user/')) {
 				$message = str_replace('@' . $search, '{' . $mentionParameterId . '}', $message);
 			}
 
 			if ($mention['type'] === 'call') {
 				$userId = '';
-				if ($chatMessage->getParticipant()->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
+				if ($chatMessage->getParticipant()?->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
 					$userId = $chatMessage->getParticipant()->getAttendee()->getActorId();
 				}
 
 				$messageParameters[$mentionParameterId] = [
 					'type' => $mention['type'],
 					'id' => $chatMessage->getRoom()->getToken(),
-					'name' => $chatMessage->getRoom()->getDisplayName($userId),
+					'name' => $chatMessage->getRoom()->getDisplayName($userId, true),
 					'call-type' => $this->getRoomType($chatMessage->getRoom()),
 					'icon-url' => $this->avatarService->getAvatarUrl($chatMessage->getRoom()),
+					'mention-id' => $search,
 				];
 			} elseif ($mention['type'] === 'guest') {
 				try {
@@ -158,6 +175,42 @@ class UserMention {
 					'type' => $mention['type'],
 					'id' => $mention['id'],
 					'name' => $displayName,
+					'mention-id' => $search,
+				];
+			} elseif ($mention['type'] === 'email') {
+				try {
+					$participant = $this->participantService->getParticipantByActor($chatMessage->getRoom(), Attendee::ACTOR_EMAILS, $mention['id']);
+					$displayName = $participant->getAttendee()->getDisplayName() ?: $this->l->t('Guest');
+				} catch (ParticipantNotFoundException) {
+					$displayName = $this->l->t('Guest');
+				}
+
+				$messageParameters[$mentionParameterId] = [
+					'type' => $mention['type'],
+					'id' => $mention['id'],
+					'name' => $displayName,
+					'mention-id' => $search,
+				];
+			} elseif ($mention['type'] === 'federated_user') {
+				try {
+					$cloudId = $this->cloudIdManager->resolveCloudId($mention['id']);
+				} catch (\Throwable) {
+					continue;
+				}
+
+				try {
+					$participant = $this->participantService->getParticipantByActor($chatMessage->getRoom(), Attendee::ACTOR_FEDERATED_USERS, $mention['id']);
+					$displayName = $participant->getAttendee()->getDisplayName() ?: $cloudId->getDisplayId();
+				} catch (ParticipantNotFoundException) {
+					$displayName = $mention['id'];
+				}
+
+				$messageParameters[$mentionParameterId] = [
+					'type' => 'user',
+					'id' => $cloudId->getUser(),
+					'name' => $displayName,
+					'server' => $cloudId->getRemote(),
+					'mention-id' => $search,
 				];
 			} elseif ($mention['type'] === 'group') {
 				$group = $this->groupManager->get($mention['id']);
@@ -171,7 +224,10 @@ class UserMention {
 					'type' => 'user-group',
 					'id' => $mention['id'],
 					'name' => $displayName,
+					'mention-id' => $search,
 				];
+			} elseif ($mention['type'] === 'team') {
+				$messageParameters[$mentionParameterId] = $this->getCircle($mention['id']);
 			} else {
 				try {
 					$displayName = $this->commentsManager->resolveDisplayName($mention['type'], $mention['id']);
@@ -185,11 +241,12 @@ class UserMention {
 					'type' => $mention['type'],
 					'id' => $mention['id'],
 					'name' => $displayName,
+					'mention-id' => $search,
 				];
 			}
 		}
 
-		if (strpos($message, '//') === 0) {
+		if (str_starts_with($message, '//')) {
 			$message = substr($message, 1);
 		}
 
@@ -205,6 +262,7 @@ class UserMention {
 		switch ($room->getType()) {
 			case Room::TYPE_ONE_TO_ONE:
 			case Room::TYPE_ONE_TO_ONE_FORMER:
+			case Room::TYPE_NOTE_TO_SELF:
 				return 'one2one';
 			case Room::TYPE_GROUP:
 				return 'group';
@@ -214,4 +272,48 @@ class UserMention {
 				throw new \InvalidArgumentException('Unknown room type');
 		}
 	}
+
+	protected function getCircle(string $circleId): array {
+		if (!$this->appManager->isEnabledForUser('circles')) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			$this->loadCircleDetails($circleId);
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		return [
+			'type' => 'circle',
+			'id' => $circleId,
+			'name' => $this->circleNames[$circleId],
+			'link' => $this->circleLinks[$circleId],
+			'mention-id' => 'team/' . $circleId,
+		];
+	}
+
+	protected function loadCircleDetails(string $circleId): void {
+		try {
+			$circlesManager = Server::get(CirclesManager::class);
+			$circlesManager->startSuperSession();
+			$circle = $circlesManager->getCircle($circleId);
+
+			$this->circleNames[$circleId] = $circle->getDisplayName();
+			$this->circleLinks[$circleId] = $circle->getUrl();
+		} catch (\Exception) {
+		} finally {
+			$circlesManager?->stopSession();
+		}
+	}
 }
