@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Command\Monitor;
@@ -33,12 +18,11 @@ use Symfony\Component\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class Room extends Base {
-	protected IDBConnection $connection;
 
-	public function __construct(IDBConnection $connection) {
+	public function __construct(
+		protected IDBConnection $connection,
+	) {
 		parent::__construct();
-
-		$this->connection = $connection;
 	}
 
 	protected function configure(): void {
@@ -71,7 +55,7 @@ class Room extends Base {
 			->where($query->expr()->eq('token', $query->createNamedParameter($token)));
 
 		$result = $query->executeQuery();
-		$roomId = (int) $result->fetchOne();
+		$roomId = (int)$result->fetchOne();
 		$result->closeCursor();
 
 		if ($roomId === 0) {
@@ -87,7 +71,7 @@ class Room extends Base {
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)));
 
 		$result = $query->executeQuery();
-		$numAttendees = (int) $result->fetchOne();
+		$numAttendees = (int)$result->fetchOne();
 		$result->closeCursor();
 
 		$numSessions = $numSessionsInCall = 0;
@@ -99,7 +83,7 @@ class Room extends Base {
 			->andWhere($query->expr()->gt('s.last_ping', $query->createNamedParameter(time() - 60, IQueryBuilder::PARAM_INT)));
 
 		$result = $query->executeQuery();
-		$numSessions = (int) $result->fetchOne();
+		$numSessions = (int)$result->fetchOne();
 		$result->closeCursor();
 
 		$query = $this->connection->getQueryBuilder();
@@ -111,7 +95,7 @@ class Room extends Base {
 			->andWhere($query->expr()->gt('s.last_ping', $query->createNamedParameter(time() - 60, IQueryBuilder::PARAM_INT)));
 
 		$result = $query->executeQuery();
-		$numSessionsInCall = (int) $result->fetchOne();
+		$numSessionsInCall = (int)$result->fetchOne();
 		$result->closeCursor();
 
 		if ($input->getOption('output') === Base::OUTPUT_FORMAT_PLAIN) {
