@@ -28,11 +28,12 @@ use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Http\Client\IClientService;
 use OCP\IRequest;
 use Psr\Log\LoggerInterface;
 
-class RecordingController extends AEnvironmentAwareController {
+class RecordingController extends AEnvironmentAwareOCSController {
 	public function __construct(
 		string $appName,
 		IRequest $request,
@@ -44,6 +45,7 @@ class RecordingController extends AEnvironmentAwareController {
 		private ParticipantService $participantService,
 		private RecordingService $recordingService,
 		private RoomService $roomService,
+		private ITimeFactory $timeFactory,
 		private LoggerInterface $logger,
 	) {
 		parent::__construct($appName, $request);
@@ -54,7 +56,7 @@ class RecordingController extends AEnvironmentAwareController {
 	 *
 	 * @param int $serverId ID of the server
 	 * @psalm-param non-negative-int $serverId
-	 * @return DataResponse<Http::STATUS_OK, array{version: float}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array<empty>, array{}>|DataResponse<Http::STATUS_INTERNAL_SERVER_ERROR, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{version: float}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, null, array{}>|DataResponse<Http::STATUS_INTERNAL_SERVER_ERROR, array{error: string}, array{}>
 	 *
 	 * 200: Welcome message returned
 	 * 404: Recording server not found or not configured
@@ -63,7 +65,7 @@ class RecordingController extends AEnvironmentAwareController {
 	public function getWelcomeMessage(int $serverId): DataResponse {
 		$recordingServers = $this->talkConfig->getRecordingServers();
 		if (empty($recordingServers) || !isset($recordingServers[$serverId])) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+			return new DataResponse(null, Http::STATUS_NOT_FOUND);
 		}
 
 		$url = rtrim($recordingServers[$serverId]['server'], '/');
@@ -81,12 +83,14 @@ class RecordingController extends AEnvironmentAwareController {
 
 		$client = $this->clientService->newClient();
 		try {
+			$timeBefore = $this->timeFactory->getTime();
 			$response = $client->get($url . '/api/v1/welcome', [
 				'verify' => $verifyServer,
 				'nextcloud' => [
 					'allow_local_address' => true,
 				],
 			]);
+			$timeAfter = $this->timeFactory->getTime();
 
 			if ($response->getHeader(\OCA\Talk\Signaling\Manager::FEATURE_HEADER)) {
 				return new DataResponse([
@@ -94,6 +98,14 @@ class RecordingController extends AEnvironmentAwareController {
 				], Http::STATUS_INTERNAL_SERVER_ERROR);
 			}
 
+			$responseTime = $this->timeFactory->getDateTime($response->getHeader('date'))->getTimestamp();
+			if (($timeBefore - Config::ALLOWED_BACKEND_TIMEOFFSET) > $responseTime
+				|| ($timeAfter + Config::ALLOWED_BACKEND_TIMEOFFSET) < $responseTime) {
+				return new DataResponse([
+					'error' => 'TIME_OUT_OF_SYNC',
+				], Http::STATUS_INTERNAL_SERVER_ERROR);
+			}
+
 			$body = $response->getBody();
 			$data = json_decode($body, true);
 
@@ -151,7 +163,7 @@ class RecordingController extends AEnvironmentAwareController {
 	/**
 	 * Update the recording status as a backend
 	 *
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 *
 	 * 200: Recording status updated successfully
 	 * 400: Updating recording status is not possible
@@ -196,7 +208,7 @@ class RecordingController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
 	private function backendStarted(array $started): DataResponse {
 		$token = $started['token'];
@@ -243,11 +255,11 @@ class RecordingController extends AEnvironmentAwareController {
 
 		$this->roomService->setCallRecording($room, $status, $participant);
 
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
 	private function backendStopped(array $stopped): DataResponse {
 		$token = $stopped['token'];
@@ -284,11 +296,11 @@ class RecordingController extends AEnvironmentAwareController {
 
 		$this->roomService->setCallRecording($room, Room::RECORDING_NONE, $participant);
 
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
 	private function backendFailed(array $failed): DataResponse {
 		$token = $failed['token'];
@@ -311,7 +323,7 @@ class RecordingController extends AEnvironmentAwareController {
 
 		$this->roomService->setCallRecording($room, Room::RECORDING_FAILED);
 
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
@@ -319,7 +331,7 @@ class RecordingController extends AEnvironmentAwareController {
 	 *
 	 * @param int $status Type of the recording
 	 * @psalm-param Room::RECORDING_* $status
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Recording started successfully
 	 * 400: Starting recording is not possible
@@ -332,13 +344,13 @@ class RecordingController extends AEnvironmentAwareController {
 		} catch (InvalidArgumentException $e) {
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
 	 * Stop the recording
 	 *
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Recording stopped successfully
 	 * 400: Stopping recording is not possible
@@ -351,14 +363,14 @@ class RecordingController extends AEnvironmentAwareController {
 		} catch (InvalidArgumentException $e) {
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
 	 * Store the recording
 	 *
 	 * @param ?string $owner User that will own the recording file. `null` is actually not allowed and will always result in a "400 Bad Request". It's only allowed code-wise to handle requests where the post data exceeded the limits, so we can return a proper error instead of "500 Internal Server Error".
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_UNAUTHORIZED, array{type: string, error: array{code: string, message: string}}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_UNAUTHORIZED, array{type: string, error: array{code: string, message: string}}, array{}>
 	 *
 	 * 200: Recording stored successfully
 	 * 400: Storing recording is not possible
@@ -398,7 +410,7 @@ class RecordingController extends AEnvironmentAwareController {
 		} catch (InvalidArgumentException $e) {
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
@@ -406,7 +418,7 @@ class RecordingController extends AEnvironmentAwareController {
 	 *
 	 * @param int $timestamp Timestamp of the notification to be dismissed
 	 * @psalm-param non-negative-int $timestamp
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Notification dismissed successfully
 	 * 400: Dismissing notification is not possible
@@ -424,7 +436,7 @@ class RecordingController extends AEnvironmentAwareController {
 		} catch (InvalidArgumentException $e) {
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 
 	/**
@@ -434,7 +446,7 @@ class RecordingController extends AEnvironmentAwareController {
 	 * @psalm-param non-negative-int $fileId
 	 * @param int $timestamp Timestamp of the notification to be dismissed
 	 * @psalm-param non-negative-int $timestamp
-	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Recording shared to chat successfully
 	 * 400: Sharing recording to chat is not possible
@@ -452,6 +464,6 @@ class RecordingController extends AEnvironmentAwareController {
 		} catch (InvalidArgumentException $e) {
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
-		return new DataResponse();
+		return new DataResponse(null);
 	}
 }
