@@ -15,6 +15,7 @@ class MessageParseEvent extends ARoomEvent {
 	public function __construct(
 		Room $room,
 		protected Message $message,
+		protected bool $allowInaccurate,
 	) {
 		parent::__construct($room);
 	}
@@ -22,4 +23,8 @@ class MessageParseEvent extends ARoomEvent {
 	public function getMessage(): Message {
 		return $this->message;
 	}
+
+	public function allowInaccurate(): bool {
+		return $this->allowInaccurate;
+	}
 }
