@@ -2,50 +2,27 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 namespace OCA\Talk\Migration;
 
 use Doctrine\DBAL\Exception\InvalidFieldNameException;
 use Doctrine\DBAL\Exception\TableNotFoundException;
-use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
-use Doctrine\DBAL\Types\Types;
 use OCP\DB\ISchemaWrapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\DB\Types;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Migration\IOutput;
 use OCP\Migration\SimpleMigrationStep;
 
 class Version2001Date20171026134605 extends SimpleMigrationStep {
-	protected IDBConnection $connection;
-
-	protected IConfig $config;
 
 	public function __construct(
-		IDBConnection $connection,
-		IConfig $config,
+		protected IDBConnection $connection,
+		protected IConfig $config,
 	) {
-		$this->connection = $connection;
-		$this->config = $config;
 	}
 
 	/**
@@ -113,7 +90,7 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 				'length' => 255,
 				'default' => '',
 			]);
-			$table->addColumn('activeSince', Types::DATETIME_MUTABLE, [
+			$table->addColumn('activeSince', Types::DATETIME, [
 				'notnull' => false,
 			]);
 			$table->addColumn('activeGuests', Types::INTEGER, [
@@ -199,7 +176,7 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 			$insert
 				->setParameter('name', $row['name'])
 				->setParameter('token', $row['token'])
-				->setParameter('type', (int) $row['type'], IQueryBuilder::PARAM_INT)
+				->setParameter('type', (int)$row['type'], IQueryBuilder::PARAM_INT)
 				->setParameter('password', $row['password']);
 			$insert->executeStatement();
 
@@ -215,7 +192,7 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 	 */
 	protected function copyParticipants(array $roomIdMap): void {
 		$insert = $this->connection->getQueryBuilder();
-		if (!$this->connection->getDatabasePlatform() instanceof PostgreSQL94Platform) {
+		if ($this->connection->getDatabaseProvider() !== IDBConnection::PLATFORM_POSTGRES) {
 			$insert->insert('talk_participants')
 				->values([
 					'userId' => $insert->createParameter('userId'),
@@ -241,20 +218,20 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
-			if (!isset($roomIdMap[(int) $row['roomId']])) {
+			if (!isset($roomIdMap[(int)$row['roomId']])) {
 				continue;
 			}
 
 			$insert
 				->setParameter('userId', $row['userId'])
-				->setParameter('roomId', $roomIdMap[(int) $row['roomId']], IQueryBuilder::PARAM_INT)
-				->setParameter('lastPing', (int) $row['lastPing'], IQueryBuilder::PARAM_INT)
+				->setParameter('roomId', $roomIdMap[(int)$row['roomId']], IQueryBuilder::PARAM_INT)
+				->setParameter('lastPing', (int)$row['lastPing'], IQueryBuilder::PARAM_INT)
 				->setParameter('sessionId', $row['sessionId'])
 			;
-			if (!$this->connection->getDatabasePlatform() instanceof PostgreSQL94Platform) {
-				$insert->setParameter('participantType', (int) $row['participantType'], IQueryBuilder::PARAM_INT);
+			if ($this->connection->getDatabaseProvider() !== IDBConnection::PLATFORM_POSTGRES) {
+				$insert->setParameter('participantType', (int)$row['participantType'], IQueryBuilder::PARAM_INT);
 			} else {
-				$insert->setParameter('participantType', (int) $row['participanttype'], IQueryBuilder::PARAM_INT);
+				$insert->setParameter('participantType', (int)$row['participanttype'], IQueryBuilder::PARAM_INT);
 			}
 			$insert->executeStatement();
 		}
@@ -287,17 +264,17 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 		}
 
 		while ($row = $result->fetch()) {
-			if (!isset($roomIdMap[(int) $row['object_id']])) {
+			if (!isset($roomIdMap[(int)$row['object_id']])) {
 				$delete
-					->setParameter('id', (int) $row['notification_id'])
+					->setParameter('id', (int)$row['notification_id'])
 				;
 				$delete->executeStatement();
 				continue;
 			}
 
 			$update
-				->setParameter('id', (int) $row['notification_id'])
-				->setParameter('newId', $roomIdMap[(int) $row['object_id']])
+				->setParameter('id', (int)$row['notification_id'])
+				->setParameter('newId', $roomIdMap[(int)$row['object_id']])
 			;
 			$update->executeStatement();
 		}
@@ -327,16 +304,14 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 
 		try {
 			$result = $query->executeQuery();
-		} catch (TableNotFoundException $e) {
-			return;
-		} catch (InvalidFieldNameException $e) {
+		} catch (TableNotFoundException|InvalidFieldNameException) {
 			return;
 		}
 
 		while ($row = $result->fetch()) {
-			if (!isset($roomIdMap[(int) $row['object_id']])) {
+			if (!isset($roomIdMap[(int)$row['object_id']])) {
 				$delete
-					->setParameter('id', (int) $row['activity_id'])
+					->setParameter('id', (int)$row['activity_id'])
 				;
 				$delete->executeStatement();
 				continue;
@@ -346,17 +321,17 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 
 			if (!isset($params['room'])) {
 				$delete
-					->setParameter('id', (int) $row['activity_id'])
+					->setParameter('id', (int)$row['activity_id'])
 				;
 				$delete->executeStatement();
 				continue;
 			}
 
-			$params['room'] = $roomIdMap[(int) $row['object_id']];
+			$params['room'] = $roomIdMap[(int)$row['object_id']];
 
 			$update
-				->setParameter('id', (int) $row['activity_id'])
-				->setParameter('newId', $roomIdMap[(int) $row['object_id']])
+				->setParameter('id', (int)$row['activity_id'])
+				->setParameter('newId', $roomIdMap[(int)$row['object_id']])
 				->setParameter('subjectParams', json_encode($params))
 			;
 			$update->executeStatement();
@@ -385,27 +360,25 @@ class Version2001Date20171026134605 extends SimpleMigrationStep {
 
 		try {
 			$result = $query->executeQuery();
-		} catch (TableNotFoundException $e) {
-			return;
-		} catch (InvalidFieldNameException $e) {
+		} catch (TableNotFoundException|InvalidFieldNameException) {
 			return;
 		}
 
 		while ($row = $result->fetch()) {
 			$params = json_decode($row['subjectparams'], true);
 
-			if (!isset($params['room']) || !isset($roomIdMap[(int) $params['room']])) {
+			if (!isset($params['room']) || !isset($roomIdMap[(int)$params['room']])) {
 				$delete
-					->setParameter('id', (int) $row['mail_id'])
+					->setParameter('id', (int)$row['mail_id'])
 				;
 				$delete->executeStatement();
 				continue;
 			}
 
-			$params['room'] = $roomIdMap[(int) $params['room']];
+			$params['room'] = $roomIdMap[(int)$params['room']];
 
 			$update
-				->setParameter('id', (int) $row['mail_id'])
+				->setParameter('id', (int)$row['mail_id'])
 				->setParameter('subjectParams', json_encode($params))
 			;
 			$update->executeStatement();
