@@ -2,30 +2,14 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Morris Jobke <hey@morrisjobke.de>
- *
- * @author Morris Jobke <hey@morrisjobke.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Service;
 
 use GuzzleHttp\Exception\ClientException;
+use GuzzleHttp\Exception\ServerException;
 use OCA\Talk\DataObjects\AccountId;
 use OCA\Talk\DataObjects\RegisterAccountData;
 use OCA\Talk\Exceptions\HostedSignalingServerAPIException;
@@ -37,27 +21,20 @@ use OCP\IL10N;
 use OCP\Security\ISecureRandom;
 use Psr\Log\LoggerInterface;
 
+/**
+ * API documentation at https://gitlab.com/strukturag/spreed-hpbservice/-/blob/master/doc/API.md
+ */
 class HostedSignalingServerService {
-	private IConfig $config;
 	/** @var mixed */
 	private $apiServerUrl;
-	private IClientService $clientService;
-	private LoggerInterface $logger;
-	private IL10N $l10n;
-	private ISecureRandom $secureRandom;
 
 	public function __construct(
-		IConfig $config,
-		IClientService $clientService,
-		LoggerInterface $logger,
-		IL10N $l10n,
-		ISecureRandom $secureRandom,
+		private IConfig $config,
+		private IClientService $clientService,
+		private LoggerInterface $logger,
+		private IL10N $l10n,
+		private ISecureRandom $secureRandom,
 	) {
-		$this->config = $config;
-		$this->clientService = $clientService;
-		$this->logger = $logger;
-		$this->l10n = $l10n;
-		$this->secureRandom = $secureRandom;
 
 		$this->apiServerUrl = $this->config->getSystemValue('talk_hardcoded_hpb_service', 'https://api.spreed.cloud');
 	}
@@ -96,7 +73,7 @@ class HostedSignalingServerService {
 			if ($response === null) {
 				$this->logger->error('Failed to request hosted signaling server trial', ['exception' => $e]);
 				$message = $this->l10n->t('Failed to request trial because the trial server is unreachable. Please try again later.');
-				throw new HostedSignalingServerAPIException($message);
+				throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 			}
 
 			$status = $response->getStatusCode();
@@ -106,16 +83,16 @@ class HostedSignalingServerService {
 					$this->logger->error('Requesting hosted signaling server trial failed: unauthorized - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it\'s URL.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_BAD_REQUEST:
 					$body = $response->getBody()->getContents();
 					if ($body) {
 						$parsedBody = json_decode($body, true);
 						if (json_last_error() !== JSON_ERROR_NONE) {
-							$this->logger->error('Requesting hosted signaling server trial failed: cannot parse JSON response - JSON error: '. json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
+							$this->logger->error('Requesting hosted signaling server trial failed: cannot parse JSON response - JSON error: ' . json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
 
 							$message = $this->l10n->t('Something unexpected happened.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 						if ($parsedBody['reason']) {
 							$message = '';
@@ -165,46 +142,46 @@ class HostedSignalingServerService {
 							// user error
 							if ($message !== '') {
 								$this->logger->warning('Requesting hosted signaling server trial failed: bad request - reason: ' . $parsedBody['reason'] . ' ' . $log);
-								throw new HostedSignalingServerAPIException($message);
+								throw new HostedSignalingServerAPIException($message, $status);
 							}
 							$this->logger->error('Requesting hosted signaling server trial failed: bad request - reason: ' . $parsedBody['reason'] . ' ' . $log);
 
 							$message = $this->l10n->t('There is a problem with the request of the trial. Please check your logs for further information.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 					}
 
 					$message = $this->l10n->t('Something unexpected happened.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_TOO_MANY_REQUESTS:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Requesting hosted signaling server trial failed: too many requests - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Too many requests are send from your servers address. Please try again later.');
-					throw new HostedSignalingServerInputException($message);
+					throw new HostedSignalingServerInputException($message, $status);
 				case Http::STATUS_CONFLICT:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Requesting hosted signaling server trial failed: already registered - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is already a trial registered for this Nextcloud instance.');
-					throw new HostedSignalingServerInputException($message);
+					throw new HostedSignalingServerInputException($message, $status);
 				case Http::STATUS_INTERNAL_SERVER_ERROR:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Requesting hosted signaling server trial failed: internal server error - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Something unexpected happened. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				default:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Requesting hosted signaling server trial failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Failed to request trial because the trial server behaved wrongly. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 			}
 		} catch (\Exception $e) {
 			$this->logger->error('Failed to request hosted signaling server trial', ['exception' => $e]);
 			$message = $this->l10n->t('Failed to request trial because the trial server is unreachable. Please try again later.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, ($e instanceof ServerException ? $e->getResponse()?->getStatusCode() : null) ?? Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		$status = $response->getStatusCode();
@@ -214,24 +191,24 @@ class HostedSignalingServerService {
 			$this->logger->error('Requesting hosted signaling server trial failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, $status);
 		}
 
 		$body = $response->getBody();
 		$data = json_decode($body, true);
 
 		if (json_last_error() !== JSON_ERROR_NONE) {
-			$this->logger->error('Requesting hosted signaling server trial failed: cannot parse JSON response - JSON error: '. json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
+			$this->logger->error('Requesting hosted signaling server trial failed: cannot parse JSON response - JSON error: ' . json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		if (!isset($data['account_id'])) {
 			$this->logger->error('Requesting hosted signaling server trial failed: no account ID transfered - HTTP status: ' . $status . ' Response body: ' . $body);
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		$accountId = (string)$data['account_id'];
@@ -243,9 +220,7 @@ class HostedSignalingServerService {
 	/**
 	 * @throws HostedSignalingServerAPIException
 	 *
-	 * @return (\ArrayAccess|array|mixed)[]|\ArrayAccess
-	 *
-	 * @psalm-return \ArrayAccess|non-empty-array{created: mixed, owner: \ArrayAccess|array, status: mixed, signaling?: \ArrayAccess|array}
+	 * @return \ArrayAccess|array{created: mixed, owner: \ArrayAccess|array{country: mixed, email: mixed, language: mixed, name: mixed, url: mixed, ...<array-key, mixed>}, status: mixed, signaling?: array, ...<array-key, mixed>}
 	 */
 	public function fetchAccountInfo(AccountId $accountId) {
 		try {
@@ -270,7 +245,7 @@ class HostedSignalingServerService {
 			if ($response === null) {
 				$this->logger->error('Trial requested but failed to get account information', ['exception' => $e]);
 				$message = $this->l10n->t('Trial requested but failed to get account information. Please check back later.');
-				throw new HostedSignalingServerAPIException($message);
+				throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 			}
 
 			$status = $response->getStatusCode();
@@ -281,16 +256,16 @@ class HostedSignalingServerService {
 					$this->logger->error('Getting the account information failed: unauthorized - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it\'s URL.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_BAD_REQUEST:
 					$body = $response->getBody()->getContents();
 					if ($body) {
 						$parsedBody = json_decode($body, true);
 						if (json_last_error() !== JSON_ERROR_NONE) {
-							$this->logger->error('Getting the account information failed: cannot parse JSON response - JSON error: '. json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
+							$this->logger->error('Getting the account information failed: cannot parse JSON response - JSON error: ' . json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
 
 							$message = $this->l10n->t('Something unexpected happened.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 						if ($parsedBody['reason']) {
 							switch ($parsedBody['reason']) {
@@ -302,46 +277,46 @@ class HostedSignalingServerService {
 									$this->logger->error('Getting the account information failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 									$message = $this->l10n->t('Failed to fetch account information because the trial server behaved wrongly. Please check back later.');
-									throw new HostedSignalingServerAPIException($message);
+									throw new HostedSignalingServerAPIException($message, $status);
 							}
 							$this->logger->error('Getting the account information failed: bad request - reason: ' . $parsedBody['reason'] . ' ' . $log);
 
 							$message = $this->l10n->t('There is a problem with fetching the account information. Please check your logs for further information.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 					}
 
 					$message = $this->l10n->t('Something unexpected happened.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_TOO_MANY_REQUESTS:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Getting the account information failed: too many requests - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Too many requests are send from your servers address. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_NOT_FOUND:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Getting the account information failed: account not found - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is no such account registered.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_INTERNAL_SERVER_ERROR:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Getting the account information failed: internal server error - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Something unexpected happened. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				default:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Getting the account information failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Failed to fetch account information because the trial server behaved wrongly. Please check back later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 			}
 		} catch (\Exception $e) {
 			$this->logger->error('Failed to request hosted signaling server trial', ['exception' => $e]);
 			$message = $this->l10n->t('Failed to fetch account information because the trial server is unreachable. Please check back later.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, ($e instanceof ServerException ? $e->getResponse()?->getStatusCode() : null) ?? Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		$status = $response->getStatusCode();
@@ -352,17 +327,17 @@ class HostedSignalingServerService {
 
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, $status);
 		}
 
 		$body = $response->getBody();
-		$data = json_decode($body, true);
+		$data = (array)json_decode($body, true);
 
 		if (json_last_error() !== JSON_ERROR_NONE) {
-			$this->logger->error('Getting the account information failed: cannot parse JSON response - JSON error: '. json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
+			$this->logger->error('Getting the account information failed: cannot parse JSON response - JSON error: ' . json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		if (!isset($data['status'])
@@ -392,7 +367,7 @@ class HostedSignalingServerService {
 			$this->logger->error('Getting the account information failed: response is missing mandatory field - data: ' . json_encode($data));
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		return $data;
@@ -400,8 +375,6 @@ class HostedSignalingServerService {
 
 	/**
 	 * @throws HostedSignalingServerAPIException
-	 *
-	 * @return void
 	 */
 	public function deleteAccount(AccountId $accountId): void {
 		try {
@@ -426,7 +399,7 @@ class HostedSignalingServerService {
 			if ($response === null) {
 				$this->logger->error('Deleting the hosted signaling server account failed', ['exception' => $e]);
 				$message = $this->l10n->t('Deleting the hosted signaling server account failed. Please check back later.');
-				throw new HostedSignalingServerAPIException($message);
+				throw new HostedSignalingServerAPIException($message, Http::STATUS_INTERNAL_SERVER_ERROR);
 			}
 
 			$status = $response->getStatusCode();
@@ -437,16 +410,16 @@ class HostedSignalingServerService {
 					$this->logger->error('Deleting the hosted signaling server account failed: unauthorized - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it\'s URL.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_BAD_REQUEST:
 					$body = $response->getBody()->getContents();
 					if ($body) {
 						$parsedBody = json_decode($body, true);
 						if (json_last_error() !== JSON_ERROR_NONE) {
-							$this->logger->error('Deleting the hosted signaling server account failed: cannot parse JSON response - JSON error: '. json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
+							$this->logger->error('Deleting the hosted signaling server account failed: cannot parse JSON response - JSON error: ' . json_last_error() . ' ' . json_last_error_msg() . ' HTTP status: ' . $status . ' Response body: ' . $body);
 
 							$message = $this->l10n->t('Something unexpected happened.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 						if ($parsedBody['reason']) {
 							switch ($parsedBody['reason']) {
@@ -458,46 +431,46 @@ class HostedSignalingServerService {
 									$this->logger->error('Deleting the hosted signaling server account failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 									$message = $this->l10n->t('Failed to delete the account because the trial server behaved wrongly. Please check back later.');
-									throw new HostedSignalingServerAPIException($message);
+									throw new HostedSignalingServerAPIException($message, $status);
 							}
 							$this->logger->error('Deleting the hosted signaling server account failed: bad request - reason: ' . $parsedBody['reason'] . ' ' . $log);
 
 							$message = $this->l10n->t('There is a problem with deleting the account. Please check your logs for further information.');
-							throw new HostedSignalingServerAPIException($message);
+							throw new HostedSignalingServerAPIException($message, $status);
 						}
 					}
 
 					$message = $this->l10n->t('Something unexpected happened.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_TOO_MANY_REQUESTS:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Deleting the hosted signaling server account failed: too many requests - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Too many requests are sent from your servers address. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_NOT_FOUND:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Deleting the hosted signaling server account failed: account not found - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('There is no such account registered.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				case Http::STATUS_INTERNAL_SERVER_ERROR:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Deleting the hosted signaling server account failed: internal server error - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Something unexpected happened. Please try again later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 				default:
 					$body = $response->getBody()->getContents();
 					$this->logger->error('Deleting the hosted signaling server account failed: something else happened - HTTP status: ' . $status . ' Response body: ' . $body);
 
 					$message = $this->l10n->t('Failed to delete the account because the trial server behaved wrongly. Please check back later.');
-					throw new HostedSignalingServerAPIException($message);
+					throw new HostedSignalingServerAPIException($message, $status);
 			}
 		} catch (\Exception $e) {
 			$this->logger->error('Deleting the hosted signaling server account failed', ['exception' => $e]);
 			$message = $this->l10n->t('Failed to delete the account because the trial server is unreachable. Please check back later.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, ($e instanceof ServerException ? $e->getResponse()?->getStatusCode() : null) ?? Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 
 		$status = $response->getStatusCode();
@@ -508,7 +481,7 @@ class HostedSignalingServerService {
 
 
 			$message = $this->l10n->t('Something unexpected happened.');
-			throw new HostedSignalingServerAPIException($message);
+			throw new HostedSignalingServerAPIException($message, $status);
 		}
 	}
 }
